==> cscec5b-sync-impl-3.0.0-20201225.123140-25-sources.jar: com/ejianc/business/sync/bean/Imgprogb.java <==
package com.ejianc.business.sync.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;

import java.math.BigDecimal;

@TableName("WJHN_IMGPROG_B") // 形象进度子表
public class Imgprogb {
    @TableId("PK_IMGPROG_B")
    private String pkImgprogb;///主键 CHAR(20) 20
    @TableField("PK_IMGPROG")
    private String pkImgprog;//主表主键 CHAR(20) 20 是
    @TableField("PK_SUBLIST")
    private String pkSublist;//分包清单主键 CHAR(20) 20 是
    @TableField("BISSETTLE")
    private String bisSettle;//是否结算 CHAR(1) 1 是
    @TableField("CSRCID")
    private String csrcId;// 来源单据主表主键 CHAR(20) 20 是
    @TableField("CSRCBID")
    private String csrcbId;// 来源单据表体主键 CHAR(20) 20 是
    @TableField("nthisfinishnum")
    private BigDecimal nthisfinishnum;
    @TableField("nthisfinishoriginmny")
    private BigDecimal nthisfinishoriginmny;
    @TableField("nprice")
    private BigDecimal nprice;

    public BigDecimal getNthisfinishoriginmny() {
        return nthisfinishoriginmny;
    }

    public void setNthisfinishoriginmny(BigDecimal nthisfinishoriginmny) {
        this.nthisfinishoriginmny = nthisfinishoriginmny;
    }

    public BigDecimal getNprice() {
        return nprice;
    }

    public void setNprice(BigDecimal nprice) {
        this.nprice = nprice;
    }

    public BigDecimal getNthisfinishnum() {
        return nthisfinishnum;
    }

    public void setNthisfinishnum(BigDecimal nthisfinishnum) {
        this.nthisfinishnum = nthisfinishnum;
    }

    private String ts;

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }

    public String getPkImgprogb() {
        return pkImgprogb;
    }

    public void setPkImgprogb(String pkImgprogb) {
        this.pkImgprogb = pkImgprogb;
    }

    public String getPkImgprog() {
        return pkImgprog;
    }

    public void setPkImgprog(String pkImgprog) {
        this.pkImgprog = pkImgprog;
    }

    public String getPkSublist() {
        return pkSublist;
    }

    public void setPkSublist(String pkSublist) {
        this.pkSublist = pkSublist;
    }

    public String getBisSettle() {
        return bisSettle;
    }

    public void setBisSettle(String bisSettle) {
        this.bisSettle = bisSettle;
    }

    public String getCsrcId() {
        return csrcId;
    }

    public void setCsrcId(String csrcId) {
        this.csrcId = csrcId;
    }

    public String getCsrcbId() {
        return csrcbId;
    }

    public void setCsrcbId(String csrcbId) {
        this.csrcbId = csrcbId;
    }

}

==> cscec5b-sync-impl-3.0.0-20210615.044152-54-sources.jar: com/ejianc/business/sync/bean/Imgprogb.java <==
package com.ejianc.business.sync.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;

import java.math.BigDecimal;

@TableName("WJHN_IMGPROG_B") // 形象进度子表
public class Imgprogb {
    @TableId("PK_IMGPROG_B")
    private String pkImgprogb;///主键 CHAR(20) 20
    @TableField("PK_IMGPROG")
    private String pkImgprog;//主表主键 CHAR(20) 20 是
    @TableField("PK_SUBLIST")
    private String pkSublist;//分包清单主键 CHAR(20) 20 是
    @TableField("BISSETTLE")
    private String bisSettle;//是否结算 CHAR(1) 1 是
    @TableField("CSRCID")
    private String csrcId;// 来源单据主表主键 CHAR(20) 20 是
    @TableField("CSRCBID")
    private String csrcbId;// 来源单据表体主键 CHAR(20) 20 是
    @TableField("nthisfinishnum")
    private BigDecimal nthisfinishnum;
    @TableField("nthisfinishoriginmny")
    private BigDecimal nthisfinishoriginmny;
    @TableField("nprice")
    private BigDecimal nprice;
    @TableField("construction")
    private String construction;

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public BigDecimal getNthisfinishoriginmny() {
        return nthisfinishoriginmny;
    }

    public void setNthisfinishoriginmny(BigDecimal nthisfinishoriginmny) {
        this.nthisfinishoriginmny = nthisfinishoriginmny;
    }

    public BigDecimal getNprice() {
        return nprice;
    }

    public void setNprice(BigDecimal nprice) {
        this.nprice = nprice;
    }

    public BigDecimal getNthisfinishnum() {
        return nthisfinishnum;
    }

    public void setNthisfinishnum(BigDecimal nthisfinishnum) {
        this.nthisfinishnum = nthisfinishnum;
    }

    private String ts;

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }

    public String getPkImgprogb() {
        return pkImgprogb;
    }

    public void setPkImgprogb(String pkImgprogb) {
        this.pkImgprogb = pkImgprogb;
    }

    public String getPkImgprog() {
        return pkImgprog;
    }

    public void setPkImgprog(String pkImgprog) {
        this.pkImgprog = pkImgprog;
    }

    public String getPkSublist() {
        return pkSublist;
    }

    public void setPkSublist(String pkSublist) {
        this.pkSublist = pkSublist;
    }

    public String getBisSettle() {
        return bisSettle;
    }

    public void setBisSettle(String bisSettle) {
        this.bisSettle = bisSettle;
    }

    public String getCsrcId() {
        return csrcId;
    }

    public void setCsrcId(String csrcId) {
        this.csrcId = csrcId;
    }

    public String getCsrcbId() {
        return csrcbId;
    }

    public void setCsrcbId(String csrcbId) {
        this.csrcbId = csrcbId;
    }

}
